@@ -133,7 +133,7 @@ MUMPS_OOC_START_LOW_LEVEL(MUMPS_INT *ierr);
 #define MUMPS_OOC_PRINT_STATS \
     F_SYMBOL(ooc_print_stats,OOC_PRINT_STATS)
 void MUMPS_CALL
-MUMPS_OOC_PRINT_STATS();
+MUMPS_OOC_PRINT_STATS(void);
 #define MUMPS_OOC_REMOVE_FILE_C \
     F_SYMBOL(ooc_remove_file_c,OOC_REMOVE_FILE_C)
 void MUMPS_CALL
