@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010-2012,2014 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -46,7 +46,7 @@
 /**                # Version 5.1  : from : 20 apr 2010     **/
 /**                                 to   : 14 feb 2011     **/
 /**                # Version 6.0  : from : 01 jan 2012     **/
-/**                                 to   : 12 nov 2014     **/
+/**                                 to   : 24 sep 2019     **/
 /**                                                        **/
 /**   NOTES      : # The cost analysis routine leaves the  **/
 /**                  memory management to malloc and free  **/
@@ -73,9 +73,9 @@
 
 static int                  C_fileNum    = 0;     /* Number of file in arg list  */
 static File                 C_fileTab[3] = {      /* File array                  */
-                              { "r" },
-                              { "r" },
-                              { "w" } };
+                              { FILEMODER },
+                              { FILEMODER },
+                              { FILEMODEW } };
 
 static const char *         C_usageList[] = {
   "gotst [<input graph file> [<input ordering file> [<output data file>]]] <options>",
@@ -110,7 +110,7 @@ char *                      argv[])
 
   if ((argc >= 2) && (argv[1][0] == '?')) {       /* If need for help */
     usagePrint (stdout, C_usageList);
-    return     (0);
+    return     (EXIT_SUCCESS);
   }
 
   fileBlockInit (C_fileTab, C_FILENBR);           /* Set default stream pointers */
@@ -119,25 +119,22 @@ char *                      argv[])
     if ((argv[i][0] != '-') || (argv[i][1] == '\0') || (argv[i][1] == '.')) { /* If found a file name */
       if (C_fileNum < C_FILEARGNBR)               /* File name has been given                         */
         fileBlockName (C_fileTab, C_fileNum ++) = argv[i];
-      else {
+      else
         errorPrint ("main: too many file names given");
-        return     (1);
-      }
     }
     else {                                       /* If found an option name */
       switch (argv[i][1]) {
         case 'H' :                               /* Give help */
         case 'h' :
           usagePrint (stdout, C_usageList);
-          return     (0);
+          return     (EXIT_SUCCESS);
         case 'V' :
           fprintf (stderr, "gotst, version " SCOTCH_VERSION_STRING "\n");
-          fprintf (stderr, "Copyright 2004,2007,2008,2010-2012,2014 IPB, Universite de Bordeaux, INRIA & CNRS, France\n");
-          fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
-          return  (0);
+          fprintf (stderr, SCOTCH_COPYRIGHT_STRING "\n");
+          fprintf (stderr, SCOTCH_LICENSE_STRING "\n");
+          return  (EXIT_SUCCESS);
         default :
           errorPrint ("main: unprocessed option '%s'", argv[i]);
-          return     (1);
       }
     }
   }
@@ -148,23 +145,18 @@ char *                      argv[])
   SCOTCH_graphLoad (&grafdat, C_filepntrgrfinp, -1, 3);
   SCOTCH_graphData (&grafdat, &baseval, &vertnbr, &verttab, &vendtab, NULL, NULL, &edgenbr, &edgetab, NULL);
 #ifdef SCOTCH_DEBUG_ALL
-  if (vendtab != (verttab + 1)) {
+  if (vendtab != (verttab + 1))
     errorPrint ("main: graph should be compact");
-    return     (1);
-  }
 #endif /* SCOTCH_DEBUG_ALL */
   if (memAllocGroup ((void **) (void *)
                      &peritab, (size_t) (vertnbr * sizeof (SCOTCH_Num)),
-                     &permtab, (size_t) (vertnbr * sizeof (SCOTCH_Num)), NULL) == NULL) {
+                     &permtab, (size_t) (vertnbr * sizeof (SCOTCH_Num)), NULL) == NULL)
     errorPrint ("main: out of memory");
-    return     (1);
-  }
+
   SCOTCH_graphOrderInit (&grafdat, &ordedat, permtab, peritab, NULL, NULL, NULL);
   SCOTCH_graphOrderLoad (&grafdat, &ordedat, C_filepntrordinp);
-  if (SCOTCH_graphOrderCheck (&grafdat, &ordedat) != 0) {
+  if (SCOTCH_graphOrderCheck (&grafdat, &ordedat) != 0)
     errorPrint ("main: invalid ordering");
-    return     (1);
-  }
 
   factorView (baseval, vertnbr, verttab, edgenbr, edgetab, permtab, peritab, C_filepntrdatout);
 
@@ -174,10 +166,7 @@ char *                      argv[])
   SCOTCH_graphOrderExit (&grafdat, &ordedat);
   SCOTCH_graphExit      (&grafdat);
 
-#ifdef COMMON_PTHREAD
-  pthread_exit ((void *) 0);                      /* Allow potential (un)compression tasks to complete */
-#endif /* COMMON_PTHREAD */
-  return (0);
+  return (EXIT_SUCCESS);
 }
 
 /*************************************/
